@@ -17,23 +17,38 @@
 #
 #   This module is free software; you can redistribute it and/or
 #   modify it under the same terms as Perl itself.
-# 
-#----------------------------------------------------------------------------
 #
-# $Id: Document.pm,v 2.65 2003/04/24 09:14:38 abw Exp $
+# REVISION
+#   $Id: Document.pm 1055 2007-04-27 11:50:40Z abw $
 #
 #============================================================================
 
 package Template::Document;
 
-require 5.004;
-
 use strict;
-use vars qw( $VERSION $ERROR $COMPERR $DEBUG $AUTOLOAD );
-use base qw( Template::Base );
+use warnings;
+use base 'Template::Base';
 use Template::Constants;
 
-$VERSION = sprintf("%d.%02d", q$Revision: 2.65 $ =~ /(\d+)\.(\d+)/);
+our $VERSION = 2.79;
+our $DEBUG   = 0 unless defined $DEBUG;
+our $ERROR   = '';
+our ($COMPERR, $AUTOLOAD, $UNICODE);
+
+BEGIN {
+    # UNICODE is supported in versions of Perl from 5.008 onwards
+    if ($UNICODE = $] > 5.007 ? 1 : 0) {
+        if ($] > 5.008) {
+            # utf8::is_utf8() available from Perl 5.8.1 onwards
+            *is_utf8 = \&utf8::is_utf8;
+        }
+        elsif ($] == 5.008) {
+            # use Encode::is_utf8() for Perl 5.8.0
+            require Encode;
+            *is_utf8 = \&Encode::is_utf8;
+        }
+    }
+}
 
 
 #========================================================================
@@ -57,34 +72,32 @@ sub new {
 
     # evaluate Perl code in $block to create sub-routine reference if necessary
     unless (ref $block) {
-	local $SIG{__WARN__} = \&catch_warnings;
-	$COMPERR = '';
+        local $SIG{__WARN__} = \&catch_warnings;
+        $COMPERR = '';
 
-	# DON'T LOOK NOW! - blindly untainting can make you go blind!
-	$block =~ /(.*)/s;
-	$block = $1;
-
-	$block = eval $block;
-#	$COMPERR .= "[$@]" if $@;
-#	return $class->error($COMPERR)
-	return $class->error($@)
-	    unless defined $block;
+        # DON'T LOOK NOW! - blindly untainting can make you go blind!
+        $block =~ /(.*)/s;
+        $block = $1;
+        
+        $block = eval $block;
+        return $class->error($@)
+            unless defined $block;
     }
 
     # same for any additional BLOCK definitions
     @$defblocks{ keys %$defblocks } = 
-	# MORE BLIND UNTAINTING - turn away if you're squeamish
-	map { 
-	    ref($_) 
-		? $_ 
-		: ( /(.*)/s && eval($1) or return $class->error($@) )
-	} values %$defblocks;
-
+        # MORE BLIND UNTAINTING - turn away if you're squeamish
+        map { 
+            ref($_) 
+                ? $_ 
+                : ( /(.*)/s && eval($1) or return $class->error($@) )
+            } values %$defblocks;
+    
     bless {
-	%$metadata,
-	_BLOCK     => $block,
-	_DEFBLOCKS => $defblocks,
-	_HOT       => 0,
+        %$metadata,
+        _BLOCK     => $block,
+        _DEFBLOCKS => $defblocks,
+        _HOT       => 0,
     }, $class;
 }
 
@@ -131,20 +144,22 @@ sub process {
 
     # check we're not already visiting this template
     return $context->throw(Template::Constants::ERROR_FILE, 
-			   "recursion into '$self->{ name }'")
-	if $self->{ _HOT } && ! $context->{ RECURSION };   ## RETURN ##
+                           "recursion into '$self->{ name }'")
+        if $self->{ _HOT } && ! $context->{ RECURSION };   ## RETURN ##
+
+    $context->visit($self, $defblocks);
 
-    $context->visit($defblocks);
     $self->{ _HOT } = 1;
     eval {
-	my $block = $self->{ _BLOCK };
-	$output = &$block($context);
+        my $block = $self->{ _BLOCK };
+        $output = &$block($context);
     };
     $self->{ _HOT } = 0;
+
     $context->leave();
 
     die $context->catch($@)
-	if $@;
+        if $@;
 	
     return $output;
 }
@@ -224,17 +239,17 @@ sub as_perl {
     $block =~ s/\s+$//;
 
     $defblocks = join('', map {
-	my $code = $defblocks->{ $_ };
-	$code =~ s/\n/\n        /g;
-	$code =~ s/\s*$//;
-	"        '$_' => $code,\n";
+        my $code = $defblocks->{ $_ };
+        $code =~ s/\n/\n        /g;
+        $code =~ s/\s*$//;
+        "        '$_' => $code,\n";
     } keys %$defblocks);
     $defblocks =~ s/\s+$//;
 
     $metadata = join('', map { 
-	my $x = $metadata->{ $_ }; 
-	$x =~ s/(['\\])/\\$1/g; 
-	"        '$_' => '$x',\n";
+        my $x = $metadata->{ $_ }; 
+        $x =~ s/(['\\])/\\$1/g; 
+        "        '$_' => '$x',\n";
     } keys %$metadata);
     $metadata =~ s/\s+$//;
 
@@ -280,12 +295,18 @@ sub write_perl_file {
         ($fh, $tmpfile) = File::Temp::tempfile( 
             DIR => File::Basename::dirname($file) 
         );
-	print $fh $class->as_perl($content) || die $!;
-	close($fh);
+        my $perlcode = $class->as_perl($content) || die $!;
+        
+        if ($UNICODE && is_utf8($perlcode)) {
+            $perlcode = "use utf8;\n\n$perlcode";
+            binmode $fh, ":utf8";
+        }
+        print $fh $perlcode;
+        close($fh);
     };
     return $class->error($@) if $@;
     return rename($tmpfile, $file)
-	|| $class->error($!);
+        || $class->error($!);
 }
 
 
@@ -445,7 +466,7 @@ An autoload method returns METADATA items.
 
 =head2 write_perl_file(\%config)
 
-This package subroutine is provided to effect persistance of compiled
+This package subroutine is provided to effect persistence of compiled
 templates.  If the COMPILE_EXT option (to indicate a file extension
 for saving compiled templates) then the Template::Parser module calls
 this subroutine before calling the new() constructor.  At this stage,
@@ -453,30 +474,40 @@ the parser has a representation of the template as text strings
 containing Perl code.  We can write that to a file, enclosed in a
 small wrapper which will allow us to susequently require() the file
 and have Perl parse and compile it into a Template::Document.  Thus we
-have persistance of compiled templates.
+have persistence of compiled templates.
 
 =head1 AUTHOR
 
-Andy Wardley E<lt>abw@andywardley.comE<gt>
+Andy Wardley E<lt>abw@wardley.orgE<gt>
 
-L<http://www.andywardley.com/|http://www.andywardley.com/>
+L<http://wardley.org/|http://wardley.org/>
 
 
 
 
 =head1 VERSION
 
-2.65, distributed as part of the
-Template Toolkit version 2.10, released on 24 July 2003.
+2.79, distributed as part of the
+Template Toolkit version 2.19, released on 27 April 2007.
 
 =head1 COPYRIGHT
 
-  Copyright (C) 1996-2003 Andy Wardley.  All Rights Reserved.
-  Copyright (C) 1998-2002 Canon Research Centre Europe Ltd.
+  Copyright (C) 1996-2007 Andy Wardley.  All Rights Reserved.
+
 
 This module is free software; you can redistribute it and/or
 modify it under the same terms as Perl itself.
 
 =head1 SEE ALSO
 
-L<Template|Template>, L<Template::Parser|Template::Parser>
\ No newline at end of file
+L<Template|Template>, L<Template::Parser|Template::Parser>
+
+=cut
+
+# Local Variables:
+# mode: perl
+# perl-indent-level: 4
+# indent-tabs-mode: nil
+# End:
+#
+# vim: expandtab shiftwidth=4:
